@@ -2,6 +2,8 @@
 ### z.B. table.muster(a, c(1,5,7,8,9)) sucht, wie oft jede Zahl in "mustervektor" in "vektor" vorkommt
 ### Warnung, wenn zusaetzliche Zahlen in Vektor stehen
 tablePattern <- function(x, pattern = NULL, weights, na.rm = TRUE, useNA = c("no", "ifany", "always")) {
+               checkmate::assert_vector(x)
+               checkmate::assert_vector(pattern, null.ok = TRUE, unique = TRUE)
                if(length(pattern)>0) {
                   additional.values <- na.omit( setdiff(x,pattern))
                   if( length( additional.values ) > 0 )   {
@@ -20,6 +22,7 @@ tablePattern <- function(x, pattern = NULL, weights, na.rm = TRUE, useNA = c("no
                 if(missing(weights)) {
                      Table <- table(y, useNA =useNA )
                   }  else  {
+                     checkmate::assert_numeric(weights, len = length(x))
                      if ( length(notInData) > 0) {
                           x <- c(as.character(x), as.character(notInData))
                           weights<- c(weights, rep(0, length(notInData)))
